@@ -13,9 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-from keystoneauth1 import adapter
-from keystoneauth1 import session as ks_session
-
+from cloudkittyclient.common import client
 from cloudkittyclient.v1 import collector
 from cloudkittyclient.v1 import info
 from cloudkittyclient.v1 import rating
@@ -23,7 +21,7 @@ from cloudkittyclient.v1 import report
 from cloudkittyclient.v1 import storage
 
 
-class Client(object):
+class Client(client.BaseClient):
 
     def __init__(self,
                  session=None,
@@ -31,23 +29,14 @@ class Client(object):
                  cacert=None,
                  insecure=False,
                  **kwargs):
-        adapter_options.setdefault('service_type', 'rating')
+        super(Client, self).__init__(
+            session=session,
+            adapter_options=adapter_options,
+            cacert=cacert,
+            insecure=insecure,
+            **kwargs
+        )
 
-        if insecure:
-            verify_cert = False
-        else:
-            if cacert:
-                verify_cert = cacert
-            else:
-                verify_cert = True
-
-        self.session = session
-        if self.session is None:
-            self.session = ks_session.Session(
-                verify=verify_cert, **kwargs)
-
-        self.api_client = adapter.Adapter(
-            session=self.session, **adapter_options)
         self.info = info.InfoManager(self.api_client)
         self.collector = collector.CollectorManager(self.api_client)
         self.rating = rating.RatingManager(self.api_client)
